==> dart_eval-0.4.0.tar.gz: lib/src/eval/compiler/statement/variable_declaration.dart <==
import 'package:analyzer/dart/ast/ast.dart';
import 'package:dart_eval/src/eval/compiler/context.dart';
import 'package:dart_eval/src/eval/compiler/expression/expression.dart';
import 'package:dart_eval/src/eval/runtime/runtime.dart';

import '../errors.dart';
import '../type.dart';
import '../variable.dart';
import 'statement.dart';

StatementInfo compileVariableDeclarationStatement(VariableDeclarationStatement s, CompilerContext ctx) {
  compileVariableDeclarationList(s.variables, ctx);
  return StatementInfo(-1);
}

void compileVariableDeclarationList(VariableDeclarationList l, CompilerContext ctx) {
  TypeRef? type;
  if (l.type != null) {
    type = TypeRef.fromAnnotation(ctx, ctx.library, l.type!);
  }

  for (final li in l.variables) {
    final init = li.initializer;
    if (init != null) {
      final res = compileExpression(init, ctx);
      if (ctx.locals.last.containsKey(li.name2.value() as String)) {
        throw CompileError('Cannot declare variable ${li.name2.value() as String} multiple times in the same scope');
      }
      if (type != null && !res.type.resolveTypeChain(ctx).isAssignableTo(ctx, type)) {
        throw CompileError(
            'Type mismatch: variable "${li.name2.value() as String}" is specified as type $type, but is initialized '
            'to an incompatible value of type ${res.type}');
      }
      if (res.name != null) {
        var _v = Variable.alloc(ctx, type ?? res.type);
        ctx.pushOp(PushNull.make(), PushNull.LEN);
        ctx.pushOp(CopyValue.make(_v.scopeFrameOffset, res.scopeFrameOffset), CopyValue.LEN);
        ctx.setLocal(li.name2.value() as String, _v);
      } else {
        ctx.setLocal(
            li.name2.value() as String,
            Variable(res.scopeFrameOffset, (type ?? res.type).copyWith(boxed: res.boxed),
                isFinal: l.isFinal,
                methodOffset: res.methodOffset,
                methodReturnType: res.methodReturnType,
                callingConvention: res.callingConvention));
      }
    }
  }
}

==> dart_eval-0.5.2.tar.gz: lib/src/eval/compiler/statement/variable_declaration.dart <==
import 'package:analyzer/dart/ast/ast.dart';
import 'package:dart_eval/src/eval/compiler/context.dart';
import 'package:dart_eval/src/eval/compiler/expression/expression.dart';
import 'package:dart_eval/src/eval/runtime/runtime.dart';

import '../errors.dart';
import '../type.dart';
import '../variable.dart';
import 'statement.dart';

final r = RegExp(r'^[a-zA-Z_][a-zA-Z0-9_]*\$');

StatementInfo compileVariableDeclarationStatement(VariableDeclarationStatement s, CompilerContext ctx) {
  compileVariableDeclarationList(s.variables, ctx);
  return StatementInfo(-1);
}

void compileVariableDeclarationList(VariableDeclarationList l, CompilerContext ctx) {
  TypeRef? type;
  if (l.type != null) {
    type = TypeRef.fromAnnotation(ctx, ctx.library, l.type!);
  }

  for (final li in l.variables) {
    final init = li.initializer;
    if (init != null) {
      final res = compileExpression(init, ctx, type);
      if (ctx.locals.last.containsKey(li.name2.value() as String)) {
        throw CompileError('Cannot declare variable ${li.name2.value() as String} multiple times in the same scope');
      }
      if (type != null && !res.type.resolveTypeChain(ctx).isAssignableTo(ctx, type)) {
        throw CompileError(
            'Type mismatch: variable "${li.name2.value() as String}" is specified as type $type, but is initialized '
            'to an incompatible value of type ${res.type}');
      }
      if (res.name != null) {
        var _v = Variable.alloc(ctx, type ?? res.type);
        ctx.pushOp(PushNull.make(), PushNull.LEN);
        ctx.pushOp(CopyValue.make(_v.scopeFrameOffset, res.scopeFrameOffset), CopyValue.LEN);
        ctx.setLocal(li.name2.value() as String, _v);
      } else {
        ctx.setLocal(
            li.name2.value() as String,
            Variable(res.scopeFrameOffset, (type ?? res.type).copyWith(boxed: res.boxed),
                isFinal: l.isFinal,
                methodOffset: res.methodOffset,
                methodReturnType: res.methodReturnType,
                callingConvention: res.callingConvention));
      }
    }
  }
}
